==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/VirtualNodeSpecBackendDefaultsClientPolicyTls.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property certificate Listener's TLS certificate.
 * @property enforce Whether the policy is enforced. Default is `true`.
 * @property ports One or more ports that the policy is enforced for.
 * @property validation Listener's Transport Layer Security (TLS) validation context.
 */
public data class VirtualNodeSpecBackendDefaultsClientPolicyTls(
    public val certificate: VirtualNodeSpecBackendDefaultsClientPolicyTlsCertificate? = null,
    public val enforce: Boolean? = null,
    public val ports: List<Int>? = null,
    public val validation: VirtualNodeSpecBackendDefaultsClientPolicyTlsValidation,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTls):
            VirtualNodeSpecBackendDefaultsClientPolicyTls =
            VirtualNodeSpecBackendDefaultsClientPolicyTls(
                certificate = javaType.certificate().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsCertificate.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                enforce = javaType.enforce().map({ args0 -> args0 }).orElse(null),
                ports = javaType.ports().map({ args0 -> args0 }),
                validation = javaType.validation().let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsValidation.Companion.toKotlin(args0)
                }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/VirtualNodeSpecBackendDefaultsClientPolicyTls.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property certificate Listener's TLS certificate.
 * @property enforce Whether the policy is enforced. Default is `true`.
 * @property ports One or more ports that the policy is enforced for.
 * @property validation Listener's Transport Layer Security (TLS) validation context.
 */
public data class VirtualNodeSpecBackendDefaultsClientPolicyTls(
    public val certificate: VirtualNodeSpecBackendDefaultsClientPolicyTlsCertificate? = null,
    public val enforce: Boolean? = null,
    public val ports: List<Int>? = null,
    public val validation: VirtualNodeSpecBackendDefaultsClientPolicyTlsValidation,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTls): VirtualNodeSpecBackendDefaultsClientPolicyTls =
            VirtualNodeSpecBackendDefaultsClientPolicyTls(
                certificate = javaType.certificate().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsCertificate.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                enforce = javaType.enforce().map({ args0 -> args0 }).orElse(null),
                ports = javaType.ports().map({ args0 -> args0 }),
                validation = javaType.validation().let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsValidation.Companion.toKotlin(args0)
                }),
            )
    }
}
